@@ -1,5 +1,5 @@
 ###
-### $Id: tictoc.R 48 2014-02-05 20:50:54Z plroebuck $
+### $Id: tictoc.R 29 2022-05-30 23:02:22Z proebuck $
 ###
 ### Stopwatch timer.
 ###
@@ -21,9 +21,9 @@ toc <- function(echo = TRUE) {
     diffTimeSecs <- proc.time()[3] - prevTime
     if (echo) {
         cat(sprintf("elapsed time is %f seconds", diffTimeSecs), "\n")
-        return(invisible())
+        invisible()
     } else {
-        return(diffTimeSecs)
+        diffTimeSecs
     }
 }
 
